/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.type;

import java.util.List;
import nl.cloudfarming.client.task.model.Task;
import nl.cloudfarming.client.task.model.TreatmentZone;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle.Messages;

/**
 * Creates node-structure for a single task
 * @author Gerben Feenstra
 */
@Messages({
"task.type.aggregatenode.treatmentzone.text=Treatment zones"
})
public class TaskChildFactory extends ChildFactory<Node> {

    private Task task;
    private static final String TREATMENTZONE_AGGREGATENODE_ICON = "nl/cloudfarming/client/task/type/Treatmentzones.png";
//    private static final String VEHICLE_AGGREGATENODE_ICON = "nl/cloudfarming/client/task/type/Vehicles.png";
            
    public TaskChildFactory(Task task) {
        this.task = task;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {

        // TreatmentZone nodes
        List<TreatmentZone> treatmentZones = task.getTreatmentZones();
        if(treatmentZones != null && treatmentZones.size() > 0){
            Children treatmentZoneChildren = Children.create(new TreatmentZoneChildFactory(treatmentZones), true);
            toPopulate.add(new TreatmentZoneAggregateNode(treatmentZoneChildren, TREATMENTZONE_AGGREGATENODE_ICON, Bundle.task_type_aggregatenode_treatmentzone_text()));
        }

        // Vehicles nodes
//        List<Vehicle> vehicles = task.getVehicles();
//        if(vehicles != null && vehicles.size() > 0){
//        Children vehicleChildren = Children.create(new VehicleChildFactory(task), true);
//        toPopulate.add(new VehicleAggregateNode(treatmentZoneChildren, "icon", "Vehicles"));
//        }

        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
