/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.type;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import nl.cloudfarming.client.task.model.Task;
import nl.cloudfarming.client.task.model.TaskManager;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.text.MultiViewEditorElement;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataNode;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.*;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.util.lookup.AbstractLookup;
import org.openide.util.lookup.InstanceContent;
import org.openide.util.lookup.ProxyLookup;
import org.openide.windows.TopComponent;

public class TaskDataObject extends MultiDataObject {

    public static final String PROJECT_ICON = "nl/cloudfarming/client/task/type/Task.png";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.task.taskdataobject");
    private InstanceContent ic;
    private Lookup intern;
    private TaskManager taskManager;
    
    public TaskDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        registerEditor(Task.MIMETYPE, true);
        
        this.ic = new InstanceContent();
        this.intern = new AbstractLookup(this.ic);

        taskManager = Lookup.getDefault().lookup(TaskManager.class);
        assert taskManager != null : "No TaskManager class found in the default lookup, unable to load the DataObject";
    }

    @Override
    protected Node createNodeDelegate() {
        Task task = taskManager.load(getPrimaryFile());
        assert task != null;
        LOGGER.log(Level.FINE, "TaskDataObject loaded {0}", System.identityHashCode(task));
        ic.add(task);
        LOGGER.log(Level.FINE, "Adding new SimpleLayer in FieldDataObject lookup");
        ic.add(new SimpleLayer(task.getName())); 
        
        // cropField.addPropertyChangeListener(this);
        LOGGER.log(Level.FINE, "Creating new node delegate for TaskDataObject");           
        DataNode delegate = (DataNode) super.createNodeDelegate();
        delegate.setIconBaseWithExtension(PROJECT_ICON);
        Node filterDelegate = new TaskNode(super.createNodeDelegate(), task);
        return filterDelegate;
    }
        
    @Override
    protected int associateLookup() {
        return 1;
    }
    
    @Override
    public Lookup getLookup() {
        return new ProxyLookup(super.getLookup(), intern);
    }
    
    @MultiViewElement.Registration(displayName = "#LBL_Task_EDITOR",
    iconBase = "nl/cloudfarming/client/task/type/Task.png",
    mimeType = "application/x-agrosense-task",
    persistenceType = TopComponent.PERSISTENCE_ONLY_OPENED,
    preferredID = "Task",
    position = 1000)
    @Messages("LBL_Task_EDITOR=Source")
    public static MultiViewEditorElement createEditor(Lookup lkp) {
        return new MultiViewEditorElement(lkp);
    }
    
   
    


    
    
}
