/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.task.type;

import java.awt.datatransfer.Transferable;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import nl.cloudfarming.client.task.model.TreatmentZone;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.util.HelpCtx;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;

/**
 * Node for a single Treatment zone
 * @author Gerben Feenstra
 */
public class TreatmentZoneNode extends AbstractNode{

    private static final String TREATMENTZONE_LAYER_NAME = "Treatment_zone_layer";
    
    public TreatmentZoneNode(TreatmentZone treatmentZone, String icon) {
        // Register layer to make this node draggable to the layerlist
        super(Children.LEAF, Lookups.fixed(new SimpleLayer(TREATMENTZONE_LAYER_NAME), treatmentZone));
        this.setIconBaseWithExtension(icon);
        this.setName(treatmentZone.getName());
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.task.treatmentzone");
    }

    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }
}
